==> ejc-assistrmat-api-3.0.0-20220915.064758-213-sources.jar: com/ejianc/business/outrmat/restitute/vo/OutRmatRestituteDetailVO.java <==
package com.ejianc.business.outrmat.restitute.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * out-退赔单明细
 * 
 * @author generator
 * 
 */
@ApiModel("out-退赔单明细")
public class OutRmatRestituteDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long materialId; // 物料主键
    private String materialName; // 物料名称
    private Long materialTypeId; // 物料类别
    private String materialTypeName; // 物料类别名称
    private String materialCode; // 物料编码
    private String spec; // 规格型号
    private String unitName; // 计量单位
    private BigDecimal exitNum; // 可退场数量
    private BigDecimal fullNum; // 完好数量
    private BigDecimal maintainNum; // 维修数量
    private BigDecimal scrapNum; // 报废数量
    private Date date; // 止租日期
    private String memo; // 备注
    private Long restituteId; // 退赔单主键
    private Long unitId; // 单位主键
    private String rentCalculationType; // 计租方式：0-日租，1-月租，2-工程量租
    private String useStatus; // 使用状态：0-停用，1-启用
    private String sourceId; // 来源主键
    private Long unitMId; // 计量单位主键
    private String unitMName; // 计量单位
    private BigDecimal numM; // 计量数量
    private BigDecimal transScale; // 转换系数

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getExitNum() {
        return exitNum;
    }

    public void setExitNum(BigDecimal exitNum) {
        this.exitNum = exitNum;
    }
    public BigDecimal getFullNum() {
        return fullNum;
    }

    public void setFullNum(BigDecimal fullNum) {
        this.fullNum = fullNum;
    }
    public BigDecimal getMaintainNum() {
        return maintainNum;
    }

    public void setMaintainNum(BigDecimal maintainNum) {
        this.maintainNum = maintainNum;
    }
    public BigDecimal getScrapNum() {
        return scrapNum;
    }

    public void setScrapNum(BigDecimal scrapNum) {
        this.scrapNum = scrapNum;
    }
    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getRestituteId() {
        return restituteId;
    }

    public void setRestituteId(Long restituteId) {
        this.restituteId = restituteId;
    }
    @ReferSerialTransfer(referCode = "share-unit")
    public Long getUnitId() {
        return unitId;
    }
    @ReferDeserialTransfer
    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public String getUseStatus() {
        return useStatus;
    }

    public void setUseStatus(String useStatus) {
        this.useStatus = useStatus;
    }

    public String getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(String rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }

    public String getUnitMName() {
        return unitMName;
    }

    public void setUnitMName(String unitMName) {
        this.unitMName = unitMName;
    }

    public BigDecimal getNumM() {
        return numM;
    }

    public void setNumM(BigDecimal numM) {
        this.numM = numM;
    }

    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }
    
}

==> ejc-assistrmat-api-3.0.0-20221101.020733-293-sources.jar: com/ejianc/business/outrmat/restitute/vo/OutRmatRestituteDetailVO.java <==
package com.ejianc.business.outrmat.restitute.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * out-退赔单明细
 * 
 * @author generator
 * 
 */
@ApiModel("out-退赔单明细")
public class OutRmatRestituteDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long materialId; // 物料主键
    private String materialName; // 物料名称
    private Long materialTypeId; // 物料类别
    private String materialTypeName; // 物料类别名称
    private String materialCode; // 物料编码
    private String spec; // 规格型号
    private String unitName; // 计量单位
    private BigDecimal exitNum; // 可退场数量
    private BigDecimal fullNum; // 完好数量
    private BigDecimal maintainNum; // 维修数量
    private BigDecimal scrapNum; // 报废数量
    private Date date; // 止租日期
    private String memo; // 备注
    private Long restituteId; // 退赔单主键
    private Long unitId; // 单位主键
    private String rentCalculationType; // 计租方式：0-日租，1-月租，2-工程量租
    private String useStatus; // 使用状态：0-停用，1-启用
    private String sourceId; // 来源主键
    private Long unitMId; // 计量单位主键
    private String unitMName; // 计量单位
    private BigDecimal numM; // 计量数量
    private BigDecimal transScale; // 转换系数
    private Long storeId; // 仓库主键
    private String storeName; // 仓库名称
    private Integer sourceType; // 材料来源,0-自购,1-租赁

    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }

    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getExitNum() {
        return exitNum;
    }

    public void setExitNum(BigDecimal exitNum) {
        this.exitNum = exitNum;
    }
    public BigDecimal getFullNum() {
        return fullNum;
    }

    public void setFullNum(BigDecimal fullNum) {
        this.fullNum = fullNum;
    }
    public BigDecimal getMaintainNum() {
        return maintainNum;
    }

    public void setMaintainNum(BigDecimal maintainNum) {
        this.maintainNum = maintainNum;
    }
    public BigDecimal getScrapNum() {
        return scrapNum;
    }

    public void setScrapNum(BigDecimal scrapNum) {
        this.scrapNum = scrapNum;
    }
    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getRestituteId() {
        return restituteId;
    }

    public void setRestituteId(Long restituteId) {
        this.restituteId = restituteId;
    }
    @ReferSerialTransfer(referCode = "share-unit")
    public Long getUnitId() {
        return unitId;
    }
    @ReferDeserialTransfer
    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public String getUseStatus() {
        return useStatus;
    }

    public void setUseStatus(String useStatus) {
        this.useStatus = useStatus;
    }

    public String getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(String rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }

    public String getUnitMName() {
        return unitMName;
    }

    public void setUnitMName(String unitMName) {
        this.unitMName = unitMName;
    }

    public BigDecimal getNumM() {
        return numM;
    }

    public void setNumM(BigDecimal numM) {
        this.numM = numM;
    }

    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }
    
}
